/*
 * jets3t : Java Extra-Tasty S3 Toolkit (for Amazon S3 online storage service)
 * This is a java.net project, see https://jets3t.dev.java.net/
 * 
 * Copyright 2006 James Murty
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */
package org.jets3t.service.utils;

import java.util.List;

/**
 * A simple container class to store the results generated by 
 * {@link FileComparer#buildDiscrepancyLists(Map, Map)}.
 * <p>
 * The following key sets are available:
 * <ul>
 * <li>onlyOnServerKeys: objects with these keys exist only in S3, not on the local computer</li>
 * <li>updatedOnServerKeys: objects with these keys exist in S3 and on the local computer, but the 
 *     contents of the objects are different and the S3 version is newer than the local one.</li>
 * <li>onlyOnClientKeys: objects with these keys exist only on the local computer, not in S3</li>
 * <li>updatedOnClientKeys: objects with these keys exist in S3 and on the local computer, but the
 *     contents of the objects are different and the local version is newer than the S3 one.</li>
 * <li>alreadySynchronisedKeys: identical objects with these keys exist in S3 and on the local computer</li>
 * </ul>
 * 
 * 
 * @author James Murty
 */
public class FileComparerResults {
    public List onlyOnServerKeys, updatedOnServerKeys, updatedOnClientKeys, onlyOnClientKeys, alreadySynchronisedKeys;

    public FileComparerResults(List onlyOnServerKeys, List updatedOnServerKeys,
        List updatedOnClientKeys, List onlyOnClientKeys, List alreadySynchronisedKeys) {
        this.onlyOnServerKeys = onlyOnServerKeys;
        this.updatedOnServerKeys = updatedOnServerKeys;
        this.updatedOnClientKeys = updatedOnClientKeys;
        this.onlyOnClientKeys = onlyOnClientKeys;
        this.alreadySynchronisedKeys = alreadySynchronisedKeys;
    }

}
